!--------------------------------------------------------------------
program checkoutput
!--------------------------------------------------------------------
! test if output source counts and rates deviate by more than 5 %
! from reference data set
! test if output source position deviate by more than 1 pixel from 
! reference data set

use dal
use errorhandling

implicit none

integer(kind=int32) :: i, itest, nrow1, nrow2
type(DataSetT)  :: set1, set2
type(TableT)    :: tab1, tab2
Type(ColumnT)   :: scol1, scol2, rcol1, rcol2, xcol1, xcol2, ycol1, ycol2
real(kind=single), dimension(:), pointer :: scts1, scts2, rate1, rate2, &
                   xima1, xima2, yima1, yima2
logical :: ok
character(len=20), dimension(3) :: &
          list = (/"emllist.fits ","emllist2.fits","emllist3.fits"/), &
          ref  = (/"emllist.ref ","emllist2.ref","emllist3.ref"/)
      
ok = .true.

do itest = 1, 1

  set1 = dataSet(list(itest), read)
  tab1 = table(set1,"SRCLIST")
  nrow1 = numberOfRows(tab1)
  scol1 = column(tab1,"SCTS", read)
  scts1 => real32Data(scol1)
  rcol1 = column(tab1,"RATE", read)
  rate1 => real32Data(rcol1)
  xcol1 = column(tab1,"X_IMA", read)
  xima1 => real32Data(xcol1)
  ycol1 = column(tab1,"Y_IMA", read)
  yima1 => real32Data(ycol1)

  set2 = dataSet(ref(itest), read)
  tab2 = table(set2,"SRCLIST")
  nrow2 = numberOfRows(tab2)
  scol2 = column(tab2,"SCTS", read)
  scts2 => real32Data(scol2)
  rcol2 = column(tab2,"RATE", read)
  rate2 => real32Data(rcol2)
  xcol2 = column(tab2,"X_IMA", read)
  xima2 => real32Data(xcol2)
  ycol2 = column(tab2,"Y_IMA", read)
  yima2 => real32Data(ycol2)

  if (nrow1 < 0.95*nrow2 .or. &
      nrow1 > 1.05*nrow2) then
    ok = .false.
  else
    do i = 0,min(nrow1-1,6)
!      print *,i,scts1(i),scts2(i),rate1(i),rate2(i)
!      print *,i,xima1(i),xima2(i),yima1(i),yima2(i)
      if (scts1(i) < 0.95*scts2(i) .or. &
          scts1(i) > 1.05*scts2(i)) then
        ok = .false.
        print *, "SCTS:",i,scts1(i),scts2(i)
      end if
      if (rate1(i) < 0.95*rate2(i) .or. &
          rate1(i) > 1.05*rate2(i)) then
        print *,"RATE:",i,rate1(i),rate2(i)
        ok = .false.
      end if
      if (xima1(i) < xima2(i)-1.0 .or. &
          xima1(i) > xima2(i)+1.0) then
        print *,"XIMA:",i,xima1(i),xima2(i) 
        ok = .false.
      end if 
      if (yima1(i) < yima2(i)-1.0 .or. &
          yima1(i) > yima2(i)+1.0) then
        print *,"YIMA:",i,yima1(i),yima2(i)
        ok = .false.
      end if 
    end do
  end if

  call release(scol1)
  call release(scol2)
  call release(rcol1)
  call release(rcol2)
  call release(xcol1)
  call release(xcol2)
  call release(ycol1)
  call release(ycol2)
  call release(tab1)
  call release(tab2)
  call release(set1)
  call release(set2)

end do

if (.not.ok) then
  print *, "test failed"
  call error("test failed","source list contains wrong values")
end if
  
end program checkoutput

